__version__ = "0.0.23"
__author__ = "shirkhan"

from shirkhan.shir_syllable import *

# utils
from shirkhan.shir_encode_decode import *
from shirkhan.shir_file import *
from shirkhan.shir_string import *
from shirkhan.shir_encryption import *
from shirkhan import shir_csv as csv
from shirkhan import shir_excel as excel
# from shirkhan import shir_wav as wave
# from shirkhan import shir_mp3 as mp3
from shirkhan.shir_email import Mailer as email
# from shirkhan import shir_textgrid as textgrid
# from shirkhan import shir_metadata as metadata
from shirkhan import shir_archive as archive

if __name__ == '__main__':
    pass
